@@ -10,7 +10,7 @@
 #include <config.h>
 #include <stdio.h>
 #include <string.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <bonobo/Bonobo.h>
 #include <libart_lgpl/art_affine.h>
 #include <libgnomecanvas/gnome-canvas.h>
@@ -210,7 +210,7 @@ impl_Bonobo_Canvas_Component_update (PortableServer_Servant     servant,
 	ArtSVP *svp = NULL;
 	Bonobo_Canvas_ArtUTA *cuta;
 
-	GnomeCanvasItemClass *gci_class = gtk_type_class (
+	GnomeCanvasItemClass *gci_class = g_type_class_ref (
 					gnome_canvas_item_get_type ());
 
 	restore_state (item, state);
@@ -940,7 +940,7 @@ typedef struct {
 
 static GType root_item_hack_get_type (void);
 #define ROOT_ITEM_HACK_TYPE (root_item_hack_get_type ())
-#define ROOT_ITEM_HACK(obj) (GTK_CHECK_CAST((obj), ROOT_ITEM_HACK_TYPE, RootItemHack))
+#define ROOT_ITEM_HACK(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROOT_ITEM_HACK_TYPE, RootItemHack))
 
 static void
 rih_dispose (GObject *obj)
@@ -996,7 +996,7 @@ rih_class_init (GObjectClass *klass)
 static GType
 root_item_hack_get_type (void)
 {
-	static GtkType type = 0;
+	static GType type = 0;
 
 	if (!type) {
 		GTypeInfo info = {
