@@ -11,18 +11,23 @@
  * Copyright 1999, 2001 Ximian, Inc.
  *                 2000 Eazel, Inc.
  */
+
+#undef GTK_DISABLE_DEPRECATED
+
 #include <config.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdio.h>
 
 #include <gdkconfig.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #if defined (GDK_WINDOWING_X11)
 #include <gdk/gdkx.h>
 #elif defined (GDK_WINDOWING_WIN32)
 #define interface _win32_interface
 #include <gdk/gdkwin32.h>
 #undef interface
+#elif defined (GDK_WINDOWING_QUARTZ)
 #else
 #error Port to this GDK backend
 #endif
@@ -89,7 +94,7 @@ control_frame_connection_died_cb (gpointer connection,
 
 	bonobo_control_disconnected (control);
 
-	dprintf ("The remote control frame died unexpectedly");
+	dbgprintf ("The remote control frame died unexpectedly");
 	bonobo_object_unref (BONOBO_OBJECT (control));
 }
 
@@ -111,7 +116,7 @@ bonobo_control_add_listener (CORBA_Object        object,
 	case ORBIT_CONNECTION_CONNECTED:
 		break;
 	default:
-		dprintf ("premature CORBA_Object death");
+		dbgprintf ("premature CORBA_Object death");
 		bonobo_exception_general_error_set (
 			ev, NULL, "Control died prematurely");
 		break;
@@ -127,9 +132,9 @@ bonobo_control_add_listener (CORBA_Object        object,
 Bonobo_Gdk_WindowId
 bonobo_control_window_id_from_x11 (guint32 x11_id)
 {
-	guchar str[32];
+	gchar str[32];
 
-	snprintf (str, 31, "%d", x11_id);
+	snprintf (str, 31, "%u", x11_id);
 	str[31] = '\0';
 
 /*	printf ("Mangled %d to '%s'\n", x11_id, str);*/
@@ -288,8 +293,7 @@ create_plug (BonoboControl *control)
 	
 	plug = bonobo_plug_new (0);
 
-	g_object_ref (G_OBJECT (plug));
-	gtk_object_sink (GTK_OBJECT (plug));
+	g_object_ref_sink (plug);
 	
 	bonobo_control_set_plug (control, BONOBO_PLUG (plug));
 
@@ -299,7 +303,7 @@ create_plug (BonoboControl *control)
 
 	g_signal_emit (control, control_signals [PLUG_CREATED], 0);
 
-	g_object_unref (G_OBJECT (plug));
+	g_object_unref (plug);
 }
 
 static int
@@ -384,7 +388,7 @@ impl_Bonobo_Control_getWindowId (PortableServer_Servant servant,
 
 	x11_id = gtk_plug_get_id (GTK_PLUG (control->priv->plug));
 		
-	dprintf ("plug id %d\n", x11_id);
+	dbgprintf ("plug id %u\n", x11_id);
 
 	return bonobo_control_window_id_from_x11 (x11_id);
 }
@@ -638,8 +642,7 @@ bonobo_control_construct (BonoboControl  *control,
 		(GSourceFunc) never_got_frame_timeout,
 		control);
 
-	control->priv->widget = g_object_ref (widget);
-	gtk_object_sink (GTK_OBJECT (widget));
+	control->priv->widget = g_object_ref_sink (widget);
 
 	gtk_container_add (GTK_CONTAINER (control->priv->plug),
 			   control->priv->widget);
@@ -731,7 +734,7 @@ bonobo_control_destroy (BonoboObject *object)
 {
 	BonoboControl *control = (BonoboControl *) object;
 
-	dprintf ("bonobo_control_destroy %p\n", object);
+	dbgprintf ("bonobo_control_destroy %p\n", object);
 
 	if (control->priv->plug)
 		bonobo_control_set_plug (control, NULL);
@@ -768,7 +771,7 @@ bonobo_control_finalize (GObject *object)
 {
 	BonoboControl *control = BONOBO_CONTROL (object);
 
-	dprintf ("bonobo_control_finalize %p\n", object);
+	dbgprintf ("bonobo_control_finalize %p\n", object);
 
 	g_free (control->priv);
 
@@ -1359,7 +1362,7 @@ bonobo_control_set_plug (BonoboControl *control,
 	if ((BonoboPlug *) control->priv->plug == plug)
 		return;
 
-	dprintf ("bonobo_control_set_plug (%p, %p) [%p]\n",
+	dbgprintf ("bonobo_control_set_plug (%p, %p) [%p]\n",
 		 control, plug, control->priv->plug);
 
 	old_plug = (BonoboPlug *) control->priv->plug;
@@ -1516,7 +1519,7 @@ bonobo_control_do_popup_full (BonoboControl       *control,
 	char    *path;
 	gboolean retval;
 
-	path = g_strdup_printf ("/popups/button%d", button);
+	path = g_strdup_printf ("/popups/button%u", button);
 
 	retval = bonobo_control_do_popup_path
 		(control, parent_menu_shell, parent_menu_item,
