@@ -17,10 +17,10 @@
 G_BEGIN_DECLS
 
 #define BONOBO_TYPE_UI_TOOLBAR_POPUP_ITEM            (bonobo_ui_toolbar_popup_item_get_type ())
-#define BONOBO_UI_TOOLBAR_POPUP_ITEM(obj)            (GTK_CHECK_CAST ((obj), BONOBO_TYPE_UI_TOOLBAR_POPUP_ITEM, BonoboUIToolbarPopupItem))
-#define BONOBO_UI_TOOLBAR_POPUP_ITEM_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), BONOBO_TYPE_UI_TOOLBAR_POPUP_ITEM, BonoboUIToolbarPopupItemClass))
-#define BONOBO_IS_UI_TOOLBAR_POPUP_ITEM(obj)	     (GTK_CHECK_TYPE ((obj), BONOBO_TYPE_UI_TOOLBAR_POPUP_ITEM))
-#define BONOBO_IS_UI_TOOLBAR_POPUP_ITEM_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), BONOBO_TYPE_UI_TOOLBAR_POPUP_ITEM))
+#define BONOBO_UI_TOOLBAR_POPUP_ITEM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), BONOBO_TYPE_UI_TOOLBAR_POPUP_ITEM, BonoboUIToolbarPopupItem))
+#define BONOBO_UI_TOOLBAR_POPUP_ITEM_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), BONOBO_TYPE_UI_TOOLBAR_POPUP_ITEM, BonoboUIToolbarPopupItemClass))
+#define BONOBO_IS_UI_TOOLBAR_POPUP_ITEM(obj)	     (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BONOBO_TYPE_UI_TOOLBAR_POPUP_ITEM))
+#define BONOBO_IS_UI_TOOLBAR_POPUP_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BONOBO_TYPE_UI_TOOLBAR_POPUP_ITEM))
 
 
 typedef struct _BonoboUIToolbarPopupItemPrivate BonoboUIToolbarPopupItemPrivate;
@@ -34,7 +34,7 @@ typedef struct {
 } BonoboUIToolbarPopupItemClass;
 
 
-GtkType    bonobo_ui_toolbar_popup_item_get_type  (void) G_GNUC_CONST;
+GType    bonobo_ui_toolbar_popup_item_get_type  (void) G_GNUC_CONST;
 GtkWidget *bonobo_ui_toolbar_popup_item_new       (void);
 void       bonobo_ui_toolbar_popup_item_construct (BonoboUIToolbarPopupItem *);
 
