@@ -1,7 +1,9 @@
+#undef GTK_DISABLE_DEPRECATED
+
 #include "config.h"
 #include <stdlib.h>
 #include <libbonoboui.h>
-#include <gtk/gtkvbox.h>
+#include <gtk/gtk.h>
 #include <libgnome/gnome-init.h>
 
 #include "container.h"
