@@ -1,9 +1,11 @@
+#undef GTK_DISABLE_DEPRECATED
+
 #include <stdlib.h>
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <bonobo/bonobo-ui-main.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 
 #include <bonobo/bonobo-ui-toolbar.h>
 #include <bonobo/bonobo-ui-toolbar-button-item.h>
